==> qtjambi-activex-6.3.3-sources.jar: io/qt/activex/QAxBaseObject.java <==
package io.qt.activex;


/**
 * <p>Static properties and signals for QAxObject</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qaxbaseobject.html">QAxBaseObject</a></p>
 */
public abstract class QAxBaseObject extends io.qt.core.QObject
    implements io.qt.activex.QAxObjectInterface
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAxBaseObject.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QAxBaseObject {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public int classContext(){
            return classContext_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static int classContext_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public java.lang.String control(){
            return control_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static java.lang.String control_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public void resetControl(){
            resetControl_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static void resetControl_native(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public void setClassContext(int classContext){
            setClassContext_native_ulong(QtJambi_LibraryUtilities.internal.nativeId(this), classContext);
        }
        private native static void setClassContext_native_ulong(long __this__nativeId, int classContext);
        
        
        @Override
        @io.qt.QtUninvokable
        public boolean setControl(java.lang.String c){
            return setControl_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), c);
        }
        private native static boolean setControl_native_cref_QString(long __this__nativeId, java.lang.String c);
        
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxbaseobject.html#exception">QAxBaseObject::exception(int,QString,QString,QString)</a></p>
     */
    public final Signal4<@io.qt.QtPrimitiveType Integer, java.lang.String, java.lang.String, java.lang.String> exception = new Signal4<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxbaseobject.html#propertyChanged">QAxBaseObject::propertyChanged(QString)</a></p>
     */
    public final Signal1<java.lang.String> propertyChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxbaseobject.html#signal">QAxBaseObject::signal(QString,int,void*)</a></p>
     */
    private final Signal3<java.lang.String, @io.qt.QtPrimitiveType Integer, io.qt.QNativePointer> signal = new Signal3<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAxBaseObject(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    protected QAxBaseObject() {
        this((io.qt.core.QObject)null);
    }
    
    protected QAxBaseObject(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAxBaseObject instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#classContext">QAxObjectInterface::classContext()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract int classContext();
    
    private native static int classContext_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#control">QAxObjectInterface::control()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract java.lang.String control();
    
    private native static java.lang.String control_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#resetControl">QAxObjectInterface::resetControl()</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void resetControl();
    
    private native static void resetControl_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#setClassContext">QAxObjectInterface::setClassContext(ulong)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void setClassContext(int classContext);
    
    private native static void setClassContext_native_ulong(long __this__nativeId, int classContext);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#setControl">QAxObjectInterface::setControl(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract boolean setControl(java.lang.String c);
    
    private native static boolean setControl_native_cref_QString(long __this__nativeId, java.lang.String c);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAxBaseObject(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAxBaseObject(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAxBaseObject instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-activex-6.4.0-sources.jar: io/qt/activex/QAxBaseObject.java <==
package io.qt.activex;


/**
 * <p>Static properties and signals for QAxObject</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qaxbaseobject.html">QAxBaseObject</a></p>
 */
public abstract class QAxBaseObject extends io.qt.core.QObject
    implements io.qt.activex.QAxObjectInterface
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAxBaseObject.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QAxBaseObject {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public int classContext(){
            return classContext_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static int classContext_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public java.lang.String control(){
            return control_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static java.lang.String control_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public void resetControl(){
            resetControl_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static void resetControl_native(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public void setClassContext(int classContext){
            setClassContext_native_ulong(QtJambi_LibraryUtilities.internal.nativeId(this), classContext);
        }
        private native static void setClassContext_native_ulong(long __this__nativeId, int classContext);
        
        
        @Override
        @io.qt.QtUninvokable
        public boolean setControl(java.lang.String c){
            return setControl_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), c);
        }
        private native static boolean setControl_native_cref_QString(long __this__nativeId, java.lang.String c);
        
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxbaseobject.html#exception">QAxBaseObject::exception(int,QString,QString,QString)</a></p>
     */
    public final Signal4<@io.qt.QtPrimitiveType Integer, java.lang.String, java.lang.String, java.lang.String> exception = new Signal4<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxbaseobject.html#propertyChanged">QAxBaseObject::propertyChanged(QString)</a></p>
     */
    public final Signal1<java.lang.String> propertyChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxbaseobject.html#signal">QAxBaseObject::signal(QString,int,void*)</a></p>
     */
    private final Signal3<java.lang.String, @io.qt.QtPrimitiveType Integer, io.qt.QNativePointer> signal = new Signal3<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAxBaseObject(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    protected QAxBaseObject() {
        this((io.qt.core.QObject)null);
    }
    
    protected QAxBaseObject(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAxBaseObject instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#classContext">QAxObjectInterface::classContext()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract int classContext();
    
    private native static int classContext_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#control">QAxObjectInterface::control()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract java.lang.String control();
    
    private native static java.lang.String control_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#resetControl">QAxObjectInterface::resetControl()</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void resetControl();
    
    private native static void resetControl_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#setClassContext">QAxObjectInterface::setClassContext(ulong)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void setClassContext(int classContext);
    
    private native static void setClassContext_native_ulong(long __this__nativeId, int classContext);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#setControl">QAxObjectInterface::setControl(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract boolean setControl(java.lang.String c);
    
    private native static boolean setControl_native_cref_QString(long __this__nativeId, java.lang.String c);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAxBaseObject(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAxBaseObject(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAxBaseObject instance, QDeclarativeConstructor constructor);
    
}
